/// <reference types="react" />
import { TransitionPlainStyle, Style, PlainStyle } from "react-motion";
import { SceneBundle, SceneBundleThunk } from "../../core";
import AnimationPhase from "./AnimationPhase";
export declare type SceneBundleThunk = () => Promise<SceneBundle>;
export declare type StyleCalculator = (style: PlainStyle, phase: AnimationPhase) => Style;
export declare type StyleCalculators = {
    container: StyleCalculator;
    loadingPlay: StyleCalculator;
    scenePlay: StyleCalculator;
};
export declare type NextPhaseChecker = (style: Style, isSceneReady: boolean) => boolean;
export declare type NextPhaseCheckers = {
    container: NextPhaseChecker;
    loadingPlay: NextPhaseChecker;
    scenePlay: NextPhaseChecker;
};
export declare type StyleKeys = "container" | "loadingPlay" | "scenePlay";
export interface InitMotionStyle extends TransitionPlainStyle {
    key: StyleKeys;
}
export declare type InitMotionStyles = InitMotionStyle[];
export declare type NumberToStyle = (style: PlainStyle, phase: AnimationPhase, isSceneReady: boolean) => {
    [key: string]: string;
};
export declare type NumberToStyles = {
    container: NumberToStyle;
    loadingPlay: NumberToStyle;
    scenePlay: NumberToStyle;
};
export declare type ArenaSceneLoadMotionProps = {
    loadingPlay: React.ReactElement<{}>;
    sceneBundleThunk: SceneBundleThunk;
    children: (bundle: SceneBundle) => React.ReactElement<{}>;
    initStyles: InitMotionStyles;
    styleCalculators: StyleCalculators;
    nextPhaseCheckers: NextPhaseCheckers;
    numberToStyles: NumberToStyles;
};
export declare type ArenaSceneLoadMotionConnectedProps = {
    actions: {
        setState: (state: State) => void;
        nextPhase: (phase: AnimationPhase) => void;
        startLeaving: () => void;
        loadSceneBundle: (sceneBundleThunk: SceneBundleThunk) => void;
    };
} & State;
export declare type State = {
    isSceneReady: boolean;
    phase: AnimationPhase;
    bundle: SceneBundle | null;
};
export declare type ExtendedStyleKeys = StyleKeys | "nextPhase";
export interface ExtendedMotionStyle extends TransitionPlainStyle {
    key: StyleKeys | "nextPhase";
}
export interface ExtendedPlainMotionStyle extends TransitionPlainStyle {
    key: StyleKeys | "nextPhase";
}
export declare type ExtendedMotionStyles = ExtendedMotionStyle[];
export declare type ExtendedPlainMotionStyles = ExtendedPlainMotionStyle[];
export declare type CombinedStyleCalculator = (prevStyles: ExtendedPlainMotionStyles) => ExtendedMotionStyles;
